import re


def parse_ps_aux(command_output: str) -> list[dict[str, any]]:
    """Parse `ps aux`command output."""
    pattern = re.compile(
        "(?P<user>\S+)\s+(?P<pid>\d+)\s+(?P<cpu>\S+)\s+(?P<mem>\S+)\s+(?P<vsz>\d+)\s+(?P<rss>\d+)\s+"
        "(?P<tty>\S+)\s+(?P<stat>\S+)\s+(?P<start>\S+)\s+(?P<time>\S+)\s+(?P<command>.+)"
    )
    return [i.groupdict() for i in pattern.finditer(command_output)]


def parse_ps_ax(command_output: str) -> list[dict[str, any]]:
    """Parse `ps -ax` command output."""
    lines = '\n'.join([i.strip() for i in command_output.splitlines() if i.strip()])
    pattern = re.compile("(?P<pid>\d+)\s+(?P<tty>\S+)\s+(?P<stat>\S+)\s+(?P<time>\S+)\s+(?P<command>.+)")
    return [i.groupdict() for i in pattern.finditer(lines)]


def parse_ps_caweL(command_output: str) -> list[dict[str, any]]:
    """Parse `ps -caweL` command output."""
    lines = '\n'.join([i.strip() for i in command_output.splitlines() if i.strip()])
    pattern = re.compile(
        "(?P<pid>\d+)\s+(?P<lwp>\d+)\s+(?P<cls>\S+)\s+"
        "(?P<pri>\S+)\s+(?P<tty>\S+)\s+(?P<time>\S+)\s+(?P<cmd>.+)"
    )
    return [i.groupdict() for i in pattern.finditer(lines)]


def parse_ps_fadel(command_output: str) -> list[dict[str, any]]:
    """Parse `ps -fadel` command output."""
    pattern = re.compile(
        "(?P<flags>\d+)\s(?P<state>\w+)\s+(?P<uid>\w+)\s+(?P<pid>\d+)\s+(?P<ppid>\d+)\s+"
        "(?P<cpu>\d+)\s+(?P<priority>\S+)\s+(?P<nice_value>\S+)\s+(?P<mem_addr>\S+)\s+(?P<size>\S+)\s+"
        "(?P<waiting_channel>\S+)\s+(?P<start_time>\S+)\s+(?P<tty>\S+)\s+(?P<time>\S+)\s+(?P<cmd>.+)"
    )
    return [i.groupdict() for i in pattern.finditer(command_output)]
